jactorch.models.vision.vgg
==========================

.. automodule:: jactorch.models.vision.vgg

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      VGG
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      make_vgg
      make_vgg_contructor
      reset_vgg_parameters
   
   

   
   
   








.. rubric:: Class VGG
.. autoclass:: VGG
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







.. rubric:: Functions

.. autofunction:: make_vgg

.. autofunction:: make_vgg_contructor

.. autofunction:: reset_vgg_parameters


